@@ -27,9 +27,9 @@
 
 #include "rendercheck.h"
 
-XRenderPictFormat **format_list;
-int nformats;
-int argb32index;
+static XRenderPictFormat **format_list;
+static int nformats;
+static int argb32index;
 
 /* Note: changing the order of these colors may disrupt tests that depend on
  * specific colors.  Just add to the end if you need.  These are
@@ -393,8 +393,8 @@ do_tests(Display *dpy, picture_info *win)
 
         pictures_solid = malloc(num_colors * sizeof(picture_info));
 	for (i = 0; i < num_colors; i++) {
-            pictures_solid[i].color = colors[i];
             XRenderColor c;
+            pictures_solid[i].color = colors[i];
             c.alpha = (int)(colors[i].a*65535);
             c.red = (int)(colors[i].r*65535);
             c.green = (int)(colors[i].g*65535);
@@ -637,6 +637,10 @@ do {								\
         if (enabled_tests & TEST_GRADIENTS) {
 	    Bool ok, group_ok = TRUE;
 
+	    printf("Beginning render to linear gradient test\n");
+	    ok = render_to_gradient_test(dpy, &pictures_1x1[0]);
+	    RECORD_RESULTS();
+
             for (i = 0; i < num_ops; i++) {
 		if (ops[i].disabled)
 		    continue;
@@ -652,11 +656,9 @@ do {								\
                            ops[i].name, pi->name);
                     
                     for (src = 0; src < num_tests; src++) {
-                        for (mask = 0; mask < num_tests; mask++) {
-                            ok = linear_gradient_test(dpy, win, pi, i,
-				&pictures_1x1[dst]);
-			    RECORD_RESULTS();
-                        }
+			ok = linear_gradient_test(dpy, win, pi, i,
+						  &pictures_1x1[src]);
+			RECORD_RESULTS();
                     }
                 }
             }
